@@ -1,3 +1,5 @@
+use std::fmt::Display;
+
 use crate::typescript::TsTypeAnn;
 use serde::{Deserialize, Serialize};
 use swc_atoms::JsWord;
@@ -33,6 +35,12 @@ pub struct Ident {
     pub optional: bool,
 }
 
+impl Display for Ident {
+    fn fmt(&self, f: &mut std::fmt::Formatter<'_>) -> std::fmt::Result {
+        write!(f, "{}{:?}", self.sym, self.span.ctxt)
+    }
+}
+
 #[cfg(feature = "arbitrary")]
 impl<'a> arbitrary::Arbitrary<'a> for Ident {
     fn arbitrary(u: &mut arbitrary::Unstructured<'_>) -> arbitrary::Result<Self> {
